==> azarashi-0.6.6-py3-none-any.whl: azarashi/qzss_dcr_lib/definition/qzss_dcr_jma_notification_on_disaster_prevention.py <==
qzss_dcr_jma_notification_on_disaster_prevention = {
    0:   "なし",
    101: "今後若干の海面変動があるかもしれません。",
    102: "今後若干の海面変動があるかもしれませんが、被害の心配はありません。",
    103: "今後もしばらく海面変動が続くと思われます。",
    104: "今後もしばらく海面変動が続くと思われますので、海水浴や磯釣り等を行う際は注意してください。",
    105: "今後もしばらく海面変動が続くと思われますので、磯釣り等を行う際は注意してください。",
    107: "現在、大津波警報・津波警報・津波注意報を発表している沿岸はありません。",
    109: "津波と満潮が重なると、津波はより高くなりますので一層厳重な警戒が必要です。",
    110: "津波と満潮が重なると、津波はより高くなりますので十分な注意が必要です。",
    111: "場所によっては、観測した津波の高さよりさらに大きな津波が到達しているおそれがあります。",
    112: "今後、津波の高さは更に高くなることも考えられます。",
    113: "沖合での観測値をもとに津波が推定されている沿岸では、早いところでは、既に津波が到達していると推定されます。",
    114: "津波による潮位変化が観測されてから最大波が観測されるまでに数時間以上かかることがあります。",
    115: "沖合での観測値であり、沿岸では津波はさらに高くなります。",
    121: "＜大津波警報＞\n" + \
         "大きな津波が襲い甚大な被害が発生します。\n" + \
         "沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "津波は繰り返し襲ってきます。警報が解除されるまで安全な場所から離れないでください。",
    122: "＜津波警報＞\n" + \
         "津波による被害が発生します。\n" + \
         "沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "津波は繰り返し襲ってきます。警報が解除されるまで安全な場所から離れないでください。",
    123: "＜津波注意報＞\n" + \
         "海の中や海岸付近は危険です。\n" + \
         "海の中にいる人はただちに海から上がって、海岸から離れてください。\n" + \
         "潮の流れが速い状態が続きますので、注意報が解除されるまで海に入ったり海岸に近づいたりしないようにしてください。",
    124: "＜津波予報(若干の海面変動)＞\n" + \
         "若干の海面変動が予想されますが、被害の心配はありません。",
    131: "警報が発表された沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "到達予想時刻は、予報区のなかで最も早く津波が到達する時刻です。場所によっては、この時刻よりもかなり遅れて津波が襲ってくることがあります。\n" + \
         "到達予想時刻から津波が最も高くなるまでに数時間以上かかることがありますので、観測された津波の高さにかかわらず、警報が解除されるまで安全な場所から離れないでください。",
    132: "場所によっては津波の高さが「予想される津波の高さ」より高くなる可能性があります。",
    141: "東日本大震災クラスの津波が来襲します。",
    142: "沖合で高い津波を観測したため大津波警報・津波警報に切り替えました。",
    143: "沖合で高い津波を観測したため大津波警報・津波警報を切り替えました。",
    144: "沖合で高い津波を観測したため大津波警報に切り替えました。",
    145: "沖合で高い津波を観測したため大津波警報を切り替えました。",
    146: "沖合で高い津波を観測したため津波警報に切り替えました。",
    147: "沖合で高い津波を観測したため津波警報を切り替えました。",
    148: "沖合で高い津波を観測したため予想される津波の高さを切り替えました。",
    149: "ただちに避難してください。",
    201: "強い揺れに警戒してください。",
    211: "津波警報等(大津波警報・津波警報あるいは津波注意報)を発表中です。",
    212: "この地震により、日本の沿岸では若干の海面変動があるかもしれませんが、被害の心配はありません。",
    213: "今後もしばらく海面変動が続くと思われますので、海水浴や磯釣り等を行う際は注意してください。",
    214: "今後もしばらく海面変動が続くと思われますので、磯釣り等を行う際は注意してください。",
    215: "この地震による津波の心配はありません。",
    216: "震源が海底の場合、津波が発生するおそれがあります。",
    217: "今後の情報に注意してください。",
    221: "太平洋の広域に津波発生の可能性があります。",
    222: "太平洋で津波発生の可能性があります。",
    223: "北西太平洋で津波発生の可能性があります。",
    224: "インド洋の広域に津波発生の可能性があります。",
    225: "インド洋で津波発生の可能性があります。",
    226: "震源の近傍で津波発生の可能性があります。",
    227: "震源の近傍で小さな津波発生の可能性がありますが、被害をもたらす津波の心配はありません。",
    228: "一般的に、この規模の地震が海域の浅い領域で発生すると、津波が発生することがあります。",
    229: "日本への津波の有無については現在調査中です。",
    230: "この地震による日本への津波の影響はありません。",
    241: "この地震について、緊急地震速報を発表しています。",
    242: "この地震について、緊急地震速報を発表しています。この地震の最大震度は2でした。",
    243: "この地震について、緊急地震速報を発表しています。この地震の最大震度は1でした。",
    244: "この地震について、緊急地震速報を発表しています。この地震で震度1以上は観測されていません。",
    245: "この地震で緊急地震速報を発表しましたが、強い揺れは観測されませんでした。",
    256: "震源要素を訂正します。",
    500: "その他の防災上の留意事項",
    "NNN*": "防災上の留意事項(コード番号：NNN)",
}

==> azarashi-0.7.3-py3-none-any.whl: azarashi/qzss_dcr_lib/definition/qzss_dcr_jma_notification_on_disaster_prevention.py <==
qzss_dcr_jma_notification_on_disaster_prevention: dict[int, str] = {
    0: "なし",
    101: "今後若干の海面変動があるかもしれません。",
    102: "今後若干の海面変動があるかもしれませんが、被害の心配はありません。",
    103: "今後もしばらく海面変動が続くと思われます。",
    104: "今後もしばらく海面変動が続くと思われますので、海水浴や磯釣り等を行う際は注意してください。",
    105: "今後もしばらく海面変動が続くと思われますので、磯釣り等を行う際は注意してください。",
    107: "現在、大津波警報・津波警報・津波注意報を発表している沿岸はありません。",
    109: "津波と満潮が重なると、津波はより高くなりますので一層厳重な警戒が必要です。",
    110: "津波と満潮が重なると、津波はより高くなりますので十分な注意が必要です。",
    111: "場所によっては、観測した津波の高さよりさらに大きな津波が到達しているおそれがあります。",
    112: "今後、津波の高さは更に高くなることも考えられます。",
    113: "沖合での観測値をもとに津波が推定されている沿岸では、早いところでは、既に津波が到達していると推定されます。",
    114: "津波による潮位変化が観測されてから最大波が観測されるまでに数時間以上かかることがあります。",
    115: "沖合での観測値であり、沿岸では津波はさらに高くなります。",
    121: "＜大津波警報＞\n" + \
         "大きな津波が襲い甚大な被害が発生します。\n" + \
         "沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "津波は繰り返し襲ってきます。警報が解除されるまで安全な場所から離れないでください。",
    122: "＜津波警報＞\n" + \
         "津波による被害が発生します。\n" + \
         "沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "津波は繰り返し襲ってきます。警報が解除されるまで安全な場所から離れないでください。",
    123: "＜津波注意報＞\n" + \
         "海の中や海岸付近は危険です。\n" + \
         "海の中にいる人はただちに海から上がって、海岸から離れてください。\n" + \
         "潮の流れが速い状態が続きますので、注意報が解除されるまで海に入ったり海岸に近づいたりしないようにしてください。",
    124: "＜津波予報(若干の海面変動)＞\n" + \
         "若干の海面変動が予想されますが、被害の心配はありません。",
    131: "警報が発表された沿岸部や川沿いにいる人はただちに高台や避難ビルなど安全な場所へ避難してください。\n" + \
         "到達予想時刻は、予報区のなかで最も早く津波が到達する時刻です。場所によっては、この時刻よりもかなり遅れて津波が襲ってくることがあります。\n" + \
         "到達予想時刻から津波が最も高くなるまでに数時間以上かかることがありますので、観測された津波の高さにかかわらず、警報が解除されるまで安全な場所から離れないでください。",
    132: "場所によっては津波の高さが「予想される津波の高さ」より高くなる可能性があります。",
    141: "東日本大震災クラスの津波が来襲します。",
    142: "沖合で高い津波を観測したため大津波警報・津波警報に切り替えました。",
    143: "沖合で高い津波を観測したため大津波警報・津波警報を切り替えました。",
    144: "沖合で高い津波を観測したため大津波警報に切り替えました。",
    145: "沖合で高い津波を観測したため大津波警報を切り替えました。",
    146: "沖合で高い津波を観測したため津波警報に切り替えました。",
    147: "沖合で高い津波を観測したため津波警報を切り替えました。",
    148: "沖合で高い津波を観測したため予想される津波の高さを切り替えました。",
    149: "ただちに避難してください。",
    201: "強い揺れに警戒してください。",
    211: "津波警報等(大津波警報・津波警報あるいは津波注意報)を発表中です。",
    212: "この地震により、日本の沿岸では若干の海面変動があるかもしれませんが、被害の心配はありません。",
    213: "今後もしばらく海面変動が続くと思われますので、海水浴や磯釣り等を行う際は注意してください。",
    214: "今後もしばらく海面変動が続くと思われますので、磯釣り等を行う際は注意してください。",
    215: "この地震による津波の心配はありません。",
    216: "震源が海底の場合、津波が発生するおそれがあります。",
    217: "今後の情報に注意してください。",
    221: "太平洋の広域に津波発生の可能性があります。",
    222: "太平洋で津波発生の可能性があります。",
    223: "北西太平洋で津波発生の可能性があります。",
    224: "インド洋の広域に津波発生の可能性があります。",
    225: "インド洋で津波発生の可能性があります。",
    226: "震源の近傍で津波発生の可能性があります。",
    227: "震源の近傍で小さな津波発生の可能性がありますが、被害をもたらす津波の心配はありません。",
    228: "一般的に、この規模の地震が海域の浅い領域で発生すると、津波が発生することがあります。",
    229: "日本への津波の有無については現在調査中です。",
    230: "この地震による日本への津波の影響はありません。",
    241: "この地震について、緊急地震速報を発表しています。",
    242: "この地震について、緊急地震速報を発表しています。この地震の最大震度は2でした。",
    243: "この地震について、緊急地震速報を発表しています。この地震の最大震度は1でした。",
    244: "この地震について、緊急地震速報を発表しています。この地震で震度1以上は観測されていません。",
    245: "この地震で緊急地震速報を発表しましたが、強い揺れは観測されませんでした。",
    256: "震源要素を訂正します。",
    500: "その他の防災上の留意事項",
    # "NNN*": "防災上の留意事項(コード番号：NNN)",
}
